@@ -26,22 +26,48 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+import json
+import logging
 import os
 
 from nusex import TEMPLATE_DIR, Template
 from nusex.errors import DeploymentError, DoesNotExist
 from nusex.helpers import cprint
 
+log = logging.getLogger(__name__)
+
+
+def run(name, project_name, force, no_installs):
+    log.debug(
+        (
+            f"Using CLI values: "
+            f"{name=}; "
+            f"{project_name=}; "
+            f"{force=}; "
+            f"{no_installs=}"
+        )
+    )
 
-def run(name, force, no_installs):
     if not os.path.isfile(TEMPLATE_DIR / f"{name}.nsx"):
         raise DoesNotExist("No template with that name exists")
 
-    if os.path.isfile("./.nusexmeta") and not force:
-        raise DeploymentError("A template has already been deployed here")
-
     template = Template(name)
-    template.deploy()
+
+    if template.data["as_addon_for"]:
+        if not os.path.isfile(".nusexmeta"):
+            raise DeploymentError("No template has been deployed here")
+
+        with open(".nusexmeta") as f:
+            t = json.load(f)["template"]
+
+        if t != template.data["as_addon_for"]:
+            raise DeploymentError("This add-on is for a different template")
+
+    else:
+        if os.path.isfile(".nusexmeta") and not force:
+            raise DeploymentError("A template has already been deployed here")
+
+    template.deploy(project_name=project_name)
     if not no_installs:
         template.install_dependencies()
 
@@ -53,6 +79,14 @@ def setup(subparsers):
         "deploy", description="Deploy an existing template."
     )
     s.add_argument("name", help="the name of the template to deploy")
+    s.add_argument(
+        "-p",
+        "--project-name",
+        help="the project name to use (default: name of parent directory)",
+        metavar="NAME",
+        default="",
+        type=lambda x: x or None,
+    )
     s.add_argument(
         "--force",
         help=(
