@@ -26,7 +26,7 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-from nusex.errors import UnsupportedFile
+from nusex.errors import TemplateError, UnsupportedFile
 
 SPEC_ID = b"\x99\x78"
 
@@ -38,7 +38,8 @@ class NSXSpecIO:
         self.defaults = {
             "files": {},
             "installs": [],
-            "as_extension_for": "",
+            "as_addon_for": "",
+            "language": "python",
         }
 
     def _process_files(self, f, data):
@@ -89,9 +90,13 @@ class NSXSpecIO:
             # Read headers.
             ef = f.read(1)
             if ef == b"\x01":
-                data["as_extension_for"] = f.read(24).decode().strip()
+                data["as_addon_for"] = f.read(24).decode().strip()
 
-            f.read(9)  # Skip reserved.
+            l = f.read(1)
+            if l == b"\x01":
+                data["language"] = f.read(12).decode().strip()
+
+            f.read(8)  # Skip reserved.
 
             # Process chunks.
             while f.peek(1):
@@ -103,19 +108,29 @@ class NSXSpecIO:
         return data
 
     def write(self, path, data):
+        if set(self.defaults.keys()) != set(data.keys()):
+            raise TemplateError("Invalid template data")
+
         with open(path, "wb") as f:
             # Identify format.
             f.write(SPEC_ID)
 
             # Write headers.
-            ef = data["as_extension_for"]
+            ef = data["as_addon_for"]
             if ef:
                 f.write(b"\x01")
                 f.write(ef.ljust(24).encode())
             else:
                 f.write(b"\x00")
 
-            f.write(b"\x00" * 9)  # Reserved space.
+            l = data["language"]
+            if l:
+                f.write(b"\x01")
+                f.write(l.ljust(12).encode())
+            else:
+                f.write(b"\x00")
+
+            f.write(b"\x00" * 8)  # Reserved space.
 
             # Files chunk starting byte.
             f.write(b"\x01")
